import { PropType, defineComponent, reactive } from 'vue';
import styles from './index.module.less';
import { InputProps, NButton, NInput } from 'naive-ui';
import icon_search from '/src/common/images/icon_search.svg';
import icon_searchActive from '/src/common/images/icon_searchActive.svg';
import { useThrottleFn } from '@vueuse/core';

export default defineComponent({
  name: 'TheSearch',
  props: {
    /** 圆角 */
    round: {
      type: Boolean as PropType<InputProps['round']>,
      default: false
    },
    border: {
      type: Boolean,
      default: true
    },
    placeholder: {
      type: String,
      default: '请输入搜索关键词'
    },
    showSearchButton: {
      type: Boolean,
      default: true
    },
    loading: {
      type: Boolean,
      default: false
    }
  },
  emits: ['search'],
  setup(props, { emit }) {
    const searchData = reactive({
      value: ''
    });
    const debouncedRequest = useThrottleFn(() => {
      if (props.loading) return;
      emit('search', searchData.value ? searchData.value.trim() : '');
    }, 500);
    return () => (
      <NInput
        class={[styles.TheSearch, props.border ? '' : styles.noBorder]}
        style={'--n-font-size: 12px;--n-height:32px'}
        round={props.round}
        placeholder={props.placeholder}
        clearable
        v-model:value={searchData.value}
        onClear={() => {
          searchData.value = '';
          debouncedRequest();
        }}
        onKeyup={(e: KeyboardEvent) => {
          e.stopPropagation();
          if (e.code === 'Enter') {
            debouncedRequest();
          }
        }}>
        {{
          prefix: () => (
            <>
              <img class={styles.default} src={icon_search} />
              <img class={styles.active} src={icon_searchActive} />
            </>
          ),
          suffix: () =>
            props.showSearchButton && (
              <NButton
                size="small"
                round
                type="primary"
                onClick={() => debouncedRequest()}>
                搜索
              </NButton>
            )
        }}
      </NInput>
    );
  }
});
