import {
  defineComponent,
  getCurrentInstance,
  onBeforeMount,
  reactive
} from 'vue';
import styles from './index.module.less';
import { useUserStore } from '/src/store/modules/users';
import { genTestUserSig, EXPIRETIME } from '/src/TUIKit/debug';
import { SDKAppID, secretKey } from '/src/main';
import { useMessage } from 'naive-ui';
import TUIChat from '/src/TUIKit/TUIComponents/container/TUIChat/index.vue';
import TUISearch from '/src/TUIKit/TUIComponents/container/TUISearch/index.vue';
import TUIConversation from '/src/TUIKit/TUIComponents/container/TUIConversation/index.vue';
import { TUICore } from '/src/TUIKit';
// import { TUIChat, TUIConversation, TUISearch } from '/src/TUIKit/TUIComponents';

export default defineComponent({
  name: 'im-chat',
  setup() {
    const instance = getCurrentInstance();
    const message = useMessage();

    const TUIKit: any = instance?.appContext.config.globalProperties.$TUIKit;
    const userStore = useUserStore();
    const userInfos = userStore.getUserInfo;

    const data = reactive({
      currentModel: 'message',
      currentConversationID: '',
      userInfo: TUICore.instance.getStore().TUIProfile.profile
    });

    const onLoginIm = () => {
      const options = genTestUserSig({
        SDKAppID,
        secretKey,
        userID: userInfos.imUserId
      });
      const userInfo = {
        userID: userInfos.imUserId,
        userSig: options.userSig
      };
      // 进页面开始登录
      TUIKit.login(userInfo)
        .then((res: any) => {
          const options = {
            ...userInfo,
            expire: new Date().getTime() + EXPIRETIME * 1000
          };
          // store.commit('setUserInfo', options);
          console.log(options, res);
          userStore.setImUserInfo(options);

          TUICore.instance.TUIServer.TUIProfile.getMyProfile().then(
            (res: any) => {
              data.userInfo = res.data;
            }
          );
        })
        .catch((error: any) => {
          message.error(error);
        });
    };

    // 开始登录
    onLoginIm();

    // 离开时退出登录
    onBeforeMount(async () => {
      if (TUIKit.isSDKReady) {
        await TUIKit.logout();
      }
    });

    const handleCurrentConversation = (value: string) => {
      data.currentModel = 'message';
      data.currentConversationID = value;
    };

    return () => (
      <div class={styles.imChat}>
        <div class="home-TUIKit-main">
          <div
            class={'conversation'}
            v-show={data.currentModel === 'conversation'}>
            <TUISearch class="search" />
            <TUIConversation current={handleCurrentConversation} />
          </div>
          <div class="chat" v-show="!env?.isH5 || currentModel === 'message'">
            <TUIChat>
              <h1>欢迎使用腾讯云即时通信IM</h1>
            </TUIChat>
          </div>
          {/* <!-- TUICallKit 组件：通话 UI 组件主体 --> */}
          {/* <TUICallKit
      :class="!showCallMini ? 'callkit-drag-container' : 'callkit-drag-container-mini'"
      :allowedMinimized="true"
      :allowedFullScreen="false"
      :beforeCalling="beforeCalling"
      :afterCalling="afterCalling"
      :onMinimized="onMinimized"
      :onMessageSentByMe="onMessageSentByMe"
    /> */}
        </div>
      </div>
    );
  }
});
